unit CreateThumbfForm;

interface


uses
   EnMisc, Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
   Dialogs, StdCtrls, Buttons, ExtCtrls, ComCtrls, INIFiles, FileCtrl;

type
   TdlgCreateThumbs = class(TForm)
      OKButton: TButton;
      CancelButton: TButton;
      GroupBox1: TGroupBox;
      Label1: TLabel;
      edtInputFolder: TEdit;
      SpeedButton1: TSpeedButton;
      Label2: TLabel;
      FilterComboBox1: TFilterComboBox;
      GroupBox2: TGroupBox;
      Label3: TLabel;
      edtOutputFolder: TEdit;
      SpeedButton2: TSpeedButton;
      DestformatRadioGroup: TRadioGroup;
      CheckBox1: TCheckBox;
      CheckBox2: TCheckBox;
      GroupBox3: TGroupBox;
      edtHeight: TEdit;
      edtWidth: TEdit;
      Label4: TLabel;
      Label5: TLabel;
      UpDown1: TUpDown;
      UpDown2: TUpDown;
      ColorBox1: TColorBox;
      Label6: TLabel;
      edtThumbnailSuffix: TEdit;
      Label7: TLabel;
      procedure FormCreate(Sender: TObject);
      procedure SpeedButton1Click(Sender: TObject);
      procedure OKButtonClick(Sender: TObject);
      procedure SpeedButton2Click(Sender: TObject);
      procedure DestformatRadioGroupClick(Sender: TObject);
      procedure UpDown1Click(Sender: TObject; Button: TUDBtnType);
      procedure CheckBox1Click(Sender: TObject);
      procedure CheckBox2Click(Sender: TObject);
      procedure FilterComboBox1Change(Sender: TObject);
      procedure edtInputFolderChange(Sender: TObject);
      procedure edtOutputFolderChange(Sender: TObject);
      procedure edtHeightChange(Sender: TObject);
      procedure edtWidthChange(Sender: TObject);
      procedure FormDestroy(Sender: TObject);
      procedure ColorBox1Change(Sender: TObject);
      procedure edtThumbnailSuffixChange(Sender: TObject);
   private
    { Private declarations }
      function GetDestFormat: TImageFormat;
   public
    { Public declarations }
      InputFolder: string;
      OutputFolder: string;
      FileNameMask: string;
      MaskPath: string;
      Mask: string;
      DestFormatStr: string;
      DestFormat: TImageFormat;
      ThumbnailHeight: integer;
      ThumbnailWidth: integer;
      ThumbnailSuffix: string;
      ThumbnailColor: TColor;
      EnlargeSmallImages: Boolean;
      OverrideDestFormat: Boolean;

   end;

var
   dlgCreateThumbs: TdlgCreateThumbs;

implementation

{$R *.dfm}

function strRight(const S: string; Len: Integer): string;
begin
   if Len >= Length(S) then
      Result := S
   else
      Result := Copy(S, Succ(Length(S)) - Len, Len);
end;

function strLastCh(const S: string): Char;
begin
   Result := S[Length(S)];
end;

function strAddSlash(const S: string): string;
begin
   Result := S;
   if strLastCh(Result) <> '\' then Result := Result + '\';
end;

function TdlgCreateThumbs.GetDestFormat: TImageFormat;
begin
   Result := ifTrueColor; { prevent compiler warning }

   case DestFormatRadioGroup.ItemIndex of
      0: begin Result := ifColor16; DestFormatStr := '16'; end;
      1: begin Result := ifColor256; DestFormatStr := '256'; end;
      2: begin Result := ifTrueColor; DestFormatStr := '16 million'; end;
      3: begin Result := ifGray256; DestFormatStr := 'Gray 256'; end;
      4: begin Result := ifGray16; DestFormatStr := 'Gray 16'; end;
      5: begin Result := ifBlackWhite; DestFormatStr := 'Black & White'; end;
   end; // case
end;

procedure TdlgCreateThumbs.FormCreate(Sender: TObject);
var
   MyIniFile: TIniFile;
begin
   FilterComboBox1.Filter := GraphicFilter(TGraphic);
   DestFormat := ifTrueColor;
   Mask := '*.bmp';
   ThumbnailHeight := 60;
   ThumbnailWidth := 60;
   EnlargeSmallImages := True;
   OverrideDestFormat := True;
   // restore settings
   MyIniFile := TIniFile.Create(ChangeFileExt(Application.ExeName, '.ini'));
   try
      // get and set the input folder
      InputFolder := MyIniFile.ReadString('Properties', 'Input Folder', 'C:\');
      edtInputFolder.Text := Inputfolder;
      // get and set the output folder
      OutputFolder := MyIniFile.ReadString('Properties', 'Output Folder', 'C:\');
      edtOutputFolder.Text := OutputFolder;
      MaskPath := strAddSlash(InputFolder) + FilterComboBox1.Mask;
      Mask := '*.bmp';
      // get & set filter index
      FilterComboBox1.ItemIndex := MyIniFile.ReadInteger('Properties', 'Graphic Type', 0);
      // get & set color
      DestFormatRadioGroup.ItemIndex := MyIniFile.ReadInteger('Properties', 'Color', 0);
      // get & set thumbnail height
      UpDown1.Position := MyIniFile.ReadInteger('Properties', 'Thumbnail Height', 0);
      // get & set thumbnail width
      UpDown2.Position := MyIniFile.ReadInteger('Properties', 'Thumbnail Width', 0);
      // get and set Override Destination Format CheckBox1
      CheckBox1.Checked := MyIniFile.ReadBool('Properties', 'Override Dest Format', True);
      // get and set Enlarge Small Images CheckBox2
      CheckBox2.Checked := MyIniFile.ReadBool('Properties', 'Enlarge Small Images', True);
       // get & set thumbnail background color
      ColorBox1.Selected := MyIniFile.ReadInteger('Properties', 'Background Color', clWhite);
      ThumbnailColor := ColorBox1.Selected;
      // get and set the input folder
      ThumbnailSuffix := MyIniFile.ReadString('Properties', 'Thumbnail Suffix', '_Thumb');
      edtThumbnailSuffix.Text := ThumbnailSuffix;
   finally MyIniFile.Free; end;
end;

procedure TdlgCreateThumbs.FormDestroy(Sender: TObject);
var
   MyIniFile: TIniFile;
begin
   // save settings
   MyIniFile := TIniFile.Create(ChangeFileExt(Application.ExeName, '.ini'));
   try
  // save input folder
      MyIniFile.WriteString('Properties', 'Input folder', InputFolder);
  // save output folder
      MyIniFile.WriteString('Properties', 'Output folder', OutputFolder);
  // save graphic type filter index
      MyIniFile.WriteInteger('Properties', 'Graphic Type', FilterComboBox1.ItemIndex);
  // save colorindex
      MyIniFile.WriteInteger('Properties', 'Color', DestFormatRadioGroup.ItemIndex);
 // save thumbnail height
      MyIniFile.WriteInteger('Properties', 'Thumbnail Height', UpDown1.Position);
 // save thumbnail width
      MyIniFile.WriteInteger('Properties', 'Thumbnail Width', UpDown2.Position);
 // save Override Destination Format CheckBox1
      MyIniFile.WriteBool('Properties', 'Override Dest Format', CheckBox1.Checked);
 // save Enlarge Small Images CheckBox2
      MyIniFile.WriteBool('Properties', 'Enlarge Small Images', CheckBox2.Checked);
 // save Thumbnail background color
      MyIniFile.ReadInteger('Properties', 'Background Color', ColorBox1.Selected);
      ThumbnailColor := ColorBox1.Selected;
 // save Thumbnail name suffix
      MyIniFile.WriteString('Properties', 'Thumbnail Suffix', ThumbnailSuffix);
      edtThumbnailSuffix.Text := ThumbnailSuffix;
   finally MyIniFile.Free; end;
end;

procedure TdlgCreateThumbs.SpeedButton1Click(Sender: TObject);
begin
   if SelectDirectory('Select Input Folder', edtInputFolder.Text, InputFolder) then
      edtInputFolder.Text := InputFolder;
end;

procedure TdlgCreateThumbs.SpeedButton2Click(Sender: TObject);
begin
   if SelectDirectory('Select Output Folder', edtOutputFolder.Text, OutPutFolder) then
      edtOutputFolder.Text := OutputFolder;
end;

procedure TdlgCreateThumbs.OKButtonClick(Sender: TObject);
begin
   DestFormat := GetDestFormat;
   if not DirectoryExists(InputFolder) then begin
      ShowMessage('The input folder does not exist!');
      Exit;
   end
   else if
      not DirectoryExists(OutputFolder) then begin
      ShowMessage('The output folder does not exist!');
      Exit;
   end;
   if MessageDlg('Create ' + DestFormatStr + ' color thumbnails of all images in the ' + InputFolder + ' folder that are of the ' +
      strRight(FilterComboBox1.Mask, 3) + ' file type and place the thumbnail images in the ' + OutPutFolder + ' folder? ', mtConfirmation, [mbYes, mbNo], 0) = mrYes then
   begin
      FileNameMask := strAddSlash(InputFolder) + FilterComboBox1.Mask;
      MaskPath := strAddSlash(InputFolder) + FilterComboBox1.Mask;
   end
   else
      ModalResult := mrNone;
end;

procedure TdlgCreateThumbs.DestformatRadioGroupClick(Sender: TObject);
begin
   DestFormat := GetDestFormat;
end;

procedure TdlgCreateThumbs.UpDown1Click(Sender: TObject;
   Button: TUDBtnType);
begin
   ThumbnailHeight := UpDown1.Position;
   ThumbnailWidth := UpDown2.Position;
end;

procedure TdlgCreateThumbs.CheckBox1Click(Sender: TObject);
begin
   EnlargeSmallImages := CheckBox1.Checked;
end;

procedure TdlgCreateThumbs.CheckBox2Click(Sender: TObject);
begin
   OverrideDestFormat := CheckBox2.Checked;
end;

procedure TdlgCreateThumbs.FilterComboBox1Change(Sender: TObject);
begin
   Mask := FilterComboBox1.Mask;
end;

procedure TdlgCreateThumbs.edtInputFolderChange(Sender: TObject);
begin
   InputFolder := edtInputFolder.Text;
end;

procedure TdlgCreateThumbs.edtOutputFolderChange(Sender: TObject);
begin
   OutputFolder := edtOutputFolder.Text;
end;

procedure TdlgCreateThumbs.edtHeightChange(Sender: TObject);
begin
   ThumbnailHeight := UpDown1.Position;
   ThumbnailWidth := UpDown2.Position;
end;

procedure TdlgCreateThumbs.edtWidthChange(Sender: TObject);
begin
   ThumbnailHeight := UpDown1.Position;
   ThumbnailWidth := UpDown2.Position;
end;

procedure TdlgCreateThumbs.ColorBox1Change(Sender: TObject);
begin
   ThumbnailColor := ColorBox1.Selected;
end;

procedure TdlgCreateThumbs.edtThumbnailSuffixChange(Sender: TObject);
begin
   ThumbnailSuffix := edtThumbnailSuffix.Text;
end;

end.

